//
// Mail.m
//
// (C) Copyright 1989-2001 Andrew C. Stone and Stone Design Corp
// All rights reserved
//

#import <Cocoa/Cocoa.h>
#import <Message/NSMailDelivery.h>
#import "Mail.h"

@implementation Mail

// run genstrings to extract these macros into a file named Strings.strings
// then, to localize to another language, add a localized variant in PB, then translate the copy:

#define EMAIL_TIT NSLocalizedStringFromTable(@"E-Mail", @"Strings", "alert title about email")
#define THANK_YOU NSLocalizedStringFromTable(@"Thank you!", @"Strings", "alert msg about thanks")

+ (BOOL)sendRichMail:(NSAttributedString *)richBody to:(NSString *)to subject:(NSString *)subject isMIME:(BOOL)isMIME
{
	NSMutableDictionary *toFromDict = [NSMutableDictionary dictionaryWithObjectsAndKeys:
		to,@"to",subject,@"subject",NSFullUserName(),@"from",NULL];
	
	NSString *from = [[NSUserDefaults standardUserDefaults] objectForKey:@"IDEmail"];
	BOOL result = YES;
	if (NOT_NULL(from)) [toFromDict setObject:from forKey:@"from"];
	
	
	// Can we even use the mail framework?
	if (![NSMailDelivery hasDeliveryClassBeenConfigured]) {
		NSLog(@"NSMailDelivery: not configured");
		// here you could notify the user, and then launch System Preferences to have them configure it... 
		return NO;
	}
	
	// we use error handling in case there is trouble in the NSMailDelivery framework
	
	NS_DURING
		
		// first we try SMPT, then if that fails, we try sendmail:
		
		if ([NSMailDelivery deliverMessage:richBody headers:toFromDict
									format:isMIME?NSMIMEMailFormat:NSASCIIMailFormat
								  protocol:NSSMTPDeliveryProtocol] ||
			[NSMailDelivery deliverMessage:richBody headers:toFromDict
									format:isMIME?NSMIMEMailFormat:NSASCIIMailFormat
								  protocol:NSSendmailDeliveryProtocol])
			NSRunAlertPanel(EMAIL_TIT,THANK_YOU,@"OK",NULL,NULL);
		
		NS_HANDLER
			
			NSLog(@"NSMailDelivery: an exception was raised: %@",[localException reason]);
			result = NO;
			
		NS_ENDHANDLER
		
		return result;
}

// Both of these go through the one single method - factoring is good programming practice!

+ (BOOL)sendRichMail:(NSAttributedString *)richBody to:(NSString *)to subject:(NSString *)subject
{
	return [self sendRichMail:richBody to:to subject:subject isMIME:YES];
}

+ (BOOL)sendMail:(NSString *)body to:(NSString *)to subject:(NSString *)subject;
{
	NSAttributedString *richBody = [[NSAttributedString alloc] initWithString:body];
	return [self sendRichMail:richBody to:to subject:subject isMIME:NO];
}

@end